==> pipewire-docs-0.2.7-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/stream_8h.js <==
var stream_8h =
[
    [ "pw_buffer", "structpw__buffer.html", "structpw__buffer" ],
    [ "pw_stream_events", "structpw__stream__events.html", "structpw__stream__events" ],
    [ "pw_time", "structpw__time.html", "structpw__time" ],
    [ "PW_STREAM_CONTROL_BRIGHTNESS", "stream_8h.html#a60e9264567c4b1a9ca108742f170826f", null ],
    [ "PW_STREAM_CONTROL_CONTRAST", "stream_8h.html#a8ce2f57ee687d3c1a099001237f5c744", null ],
    [ "PW_STREAM_CONTROL_HUE", "stream_8h.html#a757288d4538434a1ad482b2e3540c5d1", null ],
    [ "PW_STREAM_CONTROL_SATURATION", "stream_8h.html#a20f851b1e76f65bb2ec2813357bef7e2", null ],
    [ "PW_STREAM_CONTROL_VOLUME", "stream_8h.html#aa2584a304ac4732d76e60d1b9ab91a53", null ],
    [ "PW_STREAM_PROP_IS_LIVE", "stream_8h.html#ad52b27326c05835bed1c4348fabf36cc", null ],
    [ "PW_STREAM_PROP_LATENCY_MAX", "stream_8h.html#a9668edc141e07482af5339bfcb8ae146", null ],
    [ "PW_STREAM_PROP_LATENCY_MIN", "stream_8h.html#ac4fe8503ca5b1bbfe8ebc98b7662f023", null ],
    [ "PW_VERSION_STREAM_EVENTS", "stream_8h.html#af21c1b002f78067d2eca97c455970822", null ],
    [ "pw_stream_flags", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106", [
      [ "PW_STREAM_FLAG_NONE", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106aefcc7a31a05fa55c8cff7e686dd484ca", null ],
      [ "PW_STREAM_FLAG_AUTOCONNECT", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106ab648fa0c0c7adf6aa3139eddc3a9cd7c", null ],
      [ "PW_STREAM_FLAG_INACTIVE", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a2912e7520b8eb0aa5e4a5ca275f10d3b", null ],
      [ "PW_STREAM_FLAG_MAP_BUFFERS", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a615348212b647ad5d30313536ed6e125", null ],
      [ "PW_STREAM_FLAG_DRIVER", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a73692ffb4a18142df04772cf3783410c", null ],
      [ "PW_STREAM_FLAG_RT_PROCESS", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106ad569b3a7085e21df1236651fd3388a22", null ],
      [ "PW_STREAM_FLAG_NO_CONVERT", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a87c6bfacd40d4f797505fbc22bd2b9da", null ],
      [ "PW_STREAM_FLAG_EXCLUSIVE", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a79f1bdb249e79c7e71cf46759936768f", null ]
    ] ],
    [ "pw_stream_state", "stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82", [
      [ "PW_STREAM_STATE_ERROR", "stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82aae3c1d061da27957fd3a9389b29ff89e", null ],
      [ "PW_STREAM_STATE_UNCONNECTED", "stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82aae02f4af09cb65c931e95e1aa3bdd5f3", null ],
      [ "PW_STREAM_STATE_CONNECTING", "stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82a775f5777259aa54f7ad6d4c7cfa1779f", null ],
      [ "PW_STREAM_STATE_CONFIGURE", "stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82a6d38d0ac9310b1822fcc98add8e4a8d2", null ],
      [ "PW_STREAM_STATE_READY", "stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82acaf3c66b2d1446a3a5933498f52e5efc", null ],
      [ "PW_STREAM_STATE_PAUSED", "stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82a0537b5f9f722fb2faf7822cd09370825", null ],
      [ "PW_STREAM_STATE_STREAMING", "stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82af3c3b39039810d40a7c9e1ae3c6c905d", null ]
    ] ],
    [ "pw_stream_add_listener", "stream_8h.html#adfa74620109228a9cfce24b628aa130f", null ],
    [ "pw_stream_dequeue_buffer", "stream_8h.html#ab2ef0e28a1e91816f8015ef9814d18f7", null ],
    [ "pw_stream_get_control", "stream_8h.html#a2f69fd2a5f2de1fdded55ec35f05035c", null ],
    [ "pw_stream_get_name", "stream_8h.html#a751f41a0a5ce1ece31ec126b3cab4fd4", null ],
    [ "pw_stream_get_properties", "stream_8h.html#afc74d20ae2305d82aba860fde41b9e31", null ],
    [ "pw_stream_get_remote", "stream_8h.html#a8ed38eb5f4180eec0fcb96b5c249b30a", null ],
    [ "pw_stream_get_state", "stream_8h.html#a087a686c66c04e54742cc94c7a5e4e68", null ],
    [ "pw_stream_new_simple", "stream_8h.html#a7a8eafa174549733293f11ec2c646827", null ],
    [ "pw_stream_queue_buffer", "stream_8h.html#abe1c593f34080ea9c8c6231abe4e7386", null ],
    [ "pw_stream_set_control", "stream_8h.html#ab71a6afac6fc14a1bf65649afd19de4f", null ]
];

==> pipewire-docs-0.3.6-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/stream_8h.js <==
var stream_8h =
[
    [ "pw_buffer", "structpw__buffer.html", "structpw__buffer" ],
    [ "pw_stream_control", "structpw__stream__control.html", "structpw__stream__control" ],
    [ "pw_time", "structpw__time.html", "structpw__time" ],
    [ "pw_stream_events", "structpw__stream__events.html", "structpw__stream__events" ],
    [ "PW_VERSION_STREAM_EVENTS", "stream_8h.html#af21c1b002f78067d2eca97c455970822", null ],
    [ "pw_stream_flags", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106", [
      [ "PW_STREAM_FLAG_NONE", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106aefcc7a31a05fa55c8cff7e686dd484ca", null ],
      [ "PW_STREAM_FLAG_AUTOCONNECT", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106ab648fa0c0c7adf6aa3139eddc3a9cd7c", null ],
      [ "PW_STREAM_FLAG_INACTIVE", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a2912e7520b8eb0aa5e4a5ca275f10d3b", null ],
      [ "PW_STREAM_FLAG_MAP_BUFFERS", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a615348212b647ad5d30313536ed6e125", null ],
      [ "PW_STREAM_FLAG_DRIVER", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a73692ffb4a18142df04772cf3783410c", null ],
      [ "PW_STREAM_FLAG_RT_PROCESS", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106ad569b3a7085e21df1236651fd3388a22", null ],
      [ "PW_STREAM_FLAG_NO_CONVERT", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a87c6bfacd40d4f797505fbc22bd2b9da", null ],
      [ "PW_STREAM_FLAG_EXCLUSIVE", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a79f1bdb249e79c7e71cf46759936768f", null ],
      [ "PW_STREAM_FLAG_DONT_RECONNECT", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106ab111b3fc3e1d3c1c439a65dc85a3ce20", null ],
      [ "PW_STREAM_FLAG_ALLOC_BUFFERS", "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106ab95a612ea82e3d928b5d2971bcd96465", null ]
    ] ],
    [ "pw_stream_state", "stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82", [
      [ "PW_STREAM_STATE_ERROR", "stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82aae3c1d061da27957fd3a9389b29ff89e", null ],
      [ "PW_STREAM_STATE_UNCONNECTED", "stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82aae02f4af09cb65c931e95e1aa3bdd5f3", null ],
      [ "PW_STREAM_STATE_CONNECTING", "stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82a775f5777259aa54f7ad6d4c7cfa1779f", null ],
      [ "PW_STREAM_STATE_PAUSED", "stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82a0537b5f9f722fb2faf7822cd09370825", null ],
      [ "PW_STREAM_STATE_STREAMING", "stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82af3c3b39039810d40a7c9e1ae3c6c905d", null ]
    ] ],
    [ "pw_stream_add_listener", "stream_8h.html#adfa74620109228a9cfce24b628aa130f", null ],
    [ "pw_stream_dequeue_buffer", "stream_8h.html#ab2ef0e28a1e91816f8015ef9814d18f7", null ],
    [ "pw_stream_flush", "stream_8h.html#a5ef987fd1903baa7eba9b10a8cbf5e97", null ],
    [ "pw_stream_get_core", "stream_8h.html#aeb58b45b3e0d8fa804e9165d32159aa2", null ],
    [ "pw_stream_get_name", "stream_8h.html#a751f41a0a5ce1ece31ec126b3cab4fd4", null ],
    [ "pw_stream_get_properties", "stream_8h.html#afc74d20ae2305d82aba860fde41b9e31", null ],
    [ "pw_stream_get_state", "stream_8h.html#a087a686c66c04e54742cc94c7a5e4e68", null ],
    [ "pw_stream_new_simple", "stream_8h.html#a7a8eafa174549733293f11ec2c646827", null ],
    [ "pw_stream_queue_buffer", "stream_8h.html#abe1c593f34080ea9c8c6231abe4e7386", null ],
    [ "pw_stream_set_control", "stream_8h.html#a2d5e07833039ac7a202caaf297556f52", null ],
    [ "pw_stream_set_error", "stream_8h.html#a55c1224289e488e27f8d3b6e58abcd08", null ],
    [ "pw_stream_update_properties", "stream_8h.html#a065b067d55def0d2c2cedf814a5c55d0", null ]
];
